Stan Math Library: stan/math/prim/arr/fun/value_of.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
value_of.hpp File Reference
`#include <stan/math/prim/scal/fun/value_of.hpp>`
`#include <stan/math/prim/scal/meta/child_type.hpp>`
`#include <vector>`
`#include <cstddef>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
std::vector< typename child_type< T >::type > | stan::math::value_of (const std::vector< T > &x)
| Convert a std::vector of type T to a std::vector of child_type<T>::type. More...
template<>
std::vector< double > | stan::math::value_of (const std::vector< double > &x)
| Return the specified argument. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.